# Naruno Scan
This is a simple website that build withj `flet` and `KOT` modules. It's show the situation of Naruno's network.

## Contributing
Contributions to Scan are welcome! If you have any suggestions or find a bug, please open an issue on the GitHub repository. If you want to contribute code, please fork the repository and create a pull request.

## License
Scan is released under the MPL-2.0 License.
